%define snortroot /var/chroot/snort

Summary:	A libpcap-based packet sniffer/logger.
Name:		snort
Version:	1.9.1
Release:	1.0.9
Copyright:	GPL
Group:		Applications/Internet
URL:		http://www.snort.org/Files/
Source0:	%{name}-%{version}.tar.gz
Source1:	snortd-init-gd-5
Patch0:		snort-1.9.0beta5-chroot-with-logdir-fix-gd-1.diff
Patch1:		snort-1.9.1-snort.conf-gd.1.diff
BuildRoot:	%{_tmppath}/%{name}-%{release}-root
Requires:	libpcap >= 0.4
BuildRequires:	libpcap >= 0.4

%description
Snort is a libpcap-based packet sniffer/logger which 
can be used as a lightweight network intrusion detection system. 
It features rules based logging and can perform protocol analysis, 
content searching/matching and can be used to detect a variety of 
attacks and probes, such as buffer overflows, stealth port scans, 
CGI attacks, SMB probes, OS fingerprinting attempts, and much more. 
Snort has a real-time alerting capabilty, with alerts being sent to syslog, 
a seperate "alert" file, or as a WinPopup message via Samba's smbclient

%files
  %defattr(-,root,root)
  %doc ChangeLog LICENSE doc/*

  %attr(500,root,root)		%{snortroot}/sbin/*
  %attr(750,root,admin)		%dir %{snortroot}/var/log/snort
  %attr(750,snort,admin)	%dir %{snortroot}/var/log/snort/archive

  %attr(640,root,snort)		%config(noreplace)     %{snortroot}/etc/snort.conf
  %attr(640,root,snort)		%config %{snortroot}/etc/*.config
  %attr(640,root,snort)		%config %{snortroot}/etc/*.rules
  %attr(640,root,snort)		%config %{snortroot}/etc/gen-msg.map
  %attr(640,root,snort)		%config %{snortroot}/etc/sid
  %attr(640,root,snort)		%config %{snortroot}/etc/sid-msg.map
  %attr(700,root,root)		/etc/init.d/snortd

%prep
%setup -q
%patch0 -p1
%patch1 -p1

%build
  CFLAGS="$RPM_OPT_FLAGS" \
  ./configure --prefix=%{snortroot} --with-mysql \
	--with-openssl=/usr \
	--enable-smbalerts \
	--bindir=%{snortroot}/sbin \
	--mandir=%{_mandir}
  make

%install
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

  mkdir -p $RPM_BUILD_ROOT/%{snortroot}/{sbin,doc,etc,var/log/snort/archive}
  mkdir -p $RPM_BUILD_ROOT/etc/init.d

  make prefix=$RPM_BUILD_ROOT/%{snortroot} \
       bindir=$RPM_BUILD_ROOT/%{snortroot}/sbin \
       sysconfdir=$RPM_BUILD_ROOT/%{snortroot}/etc \
       mandir=$RPM_BUILD_ROOT/%{_mandir} install

  # Initscript
  install %{SOURCE1} $RPM_BUILD_ROOT/etc/init.d/snortd

  # Rules
  install -m0640 rules/* $RPM_BUILD_ROOT/%{snortroot}/etc

  cd etc
  for i in classification.config gen-msg.map reference.config sid sid-msg.map snort.conf
  do
    install -m0640 $i $RPM_BUILD_ROOT/%{snortroot}/etc/$i
  done

%pre
  if [ $1 = 1 ] ; then
    useradd -M -r -d %{snortroot} -s /bin/false -c "Snort User" snort 2> /dev/null || true
    groupadd -r snort 2> /dev/null || true
  fi

%post
  chown -R snort.snort %{snortroot}/var/log/snort

  if [ -f /var/lock/subsys/snort ]; then
    /etc/init.d/snortd restart || true
  fi

%preun
  if [ $1 = 0 ] ; then
    /etc/init.d/snortd stop || true
    /sbin/chkconfig --del snortd || true
  fi

%postun
  if [ $1 = 0 ] ; then
    userdel snort 2> /dev/null || true
    groupdel snort 2> /dev/null || true
  fi

%clean
  [ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT

%changelog
* Fri Mar 07 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.9.1, Release 1.0.9
  - s/snort/snortd/ in %post.

* Thu Mar 06 2003 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.9.1, Release 1.0.8
  - Upgrade to 1.9.1 to fix RPC decoding vulnerability.
  - Package taken from IDDS, changelog removed.

* Mon Feb 11 2002 Ryan W. Maple <ryan@guardiandigital.com>
- Release 1.2.0
  - Initial build for EnGarde v1.2 (Parry).
  - Removed pre-EnGarde changelog.

* Sun Aug 19 2001 Dave Wreski <dave@guardiandigital.com>
- Version 1.8.1, Release 1.1.2
  - upgrade to 1.8.1
  - build snort.conf correctly

* Tue Aug 07 2001 Dave Wreski <dave@guardiandigital.com>
- Version 1.8.1-beta7, Release 1.1.1
  - Upgrade to 1.8.1-beta7

* Tue Aug 07 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.1.0
  - Initial build for EnGarde v1.1 (Balestra).

* Thu Mar 29 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.7
  - Disabled starting by default.

* Wed Mar 28 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.6
  - Rebuild against libmysqlclient.so.10

* Tue Mar 27 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.[45]
  - Updated initscript.

* Wed Feb 28 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.[23]
  - We are now using the whitehats.com ruleset.
  - Fixed a bug in the initscript (log should be relatitve to chroot).
  - defrag preprocessor?
  - stream preprocessor?

* Mon Feb 05 2001 Ryan W. Maple <ryan@guardiandigital.com>
- Version 1.7, Release 1.0.1
  - Moved the package into production (Release change).
  - Took out all the rc.d stuff.
  - Modified chkconfig line to only run snort in runlevel 3.
  - Put man pages in %{_mandir}.  They were going in the chroot.
  - Changed initscript to stop using rc.d.
  - Changed initscript to use '/var/chroot/snort' for SNORTHOME.
